[System.Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms") | Out-Null
Add-Type -AssemblyName System.IO.Compression.FileSystem

Function IsFolderEmpty($fld) {
    (Get-ChildItem $fld -force | Select-Object -First 1 | Measure-Object).Count -eq 0
}

Function Get-Folder($initialDirectory) {  
    $dlg = New-Object System.Windows.Forms.FolderBrowserDialog
    $dlg.Description = "Vyberte sloku pro staen CSS Dedicated Server, je doporueno vytvoit / vybrat przdnou sloku. Vybran sloka by se nemla nachzet ve Steamu"
    $dlg.ShowDialog() | Out-Null
    $dlg.SelectedPath
}

Function GetSteamAppPath($id, $defaultdir) {
    $key = "HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\Steam App $id"
    if (Test-Path $key) {
        $loc = (Get-ItemProperty $key).InstallLocation
        Write-Host "Found steam app id $id in $loc"
        return $loc
    }
    Write-Host "Failed to find steam app $id in installed apps, looking for Steam"
    $key = "HKLM:\Software\WOW6432Node\Valve\Steam"
    if (Test-Path $key) {
        $loc = (Get-ItemProperty $key).InstallPath
        Write-Host "Found Steam in $loc, checking SteamApps folder"
        $loc += "\SteamApps\common\" + $defaultdir
        if (Test-Path $loc) {
            Write-Host "Found steam app id $id in $loc"
            return $loc
        }
        Write-Host "Failed to find steam app $id in SteamApps folder"
    }
    else {
        Write-Host "Failed to find Steam"
    }
}

# pick folder
Write-Host "Selecting destination folder"
$fld = Get-Folder
if (-not $fld) {
    Exit
}
if (-not (IsFolderEmpty $fld)) {
    $reply = [System.Windows.Forms.MessageBox]::Show("Je doporueno vybrat przdnou sloku. Vybran sloka ($fld) nen przdn. Pokraovat?", "Varovn", "YesNo", "Warning", "Button2")
    if ($reply -ne "Yes") {
        Exit
    }
    Write-Host "Continuing even though the selected directory is not empty"
}

# download steamcmd
if (Test-Path "$fld/steamcmd/steamcmd.exe") {
    Write-Host "Found SteamCMD in the destination folder, skipping download"
}
else {
    Write-Host "Downloading SteamCMD to $fld/steamcmd.zip"
    $zipfile = "$fld/steamcmd.zip"
    Invoke-WebRequest -Uri "https://steamcdn-a.akamaihd.net/client/installer/steamcmd.zip" -OutFile $zipfile
    Write-Host "Extracting SteamCMD to $fld/steamcmd"
    [System.IO.Compression.ZipFile]::ExtractToDirectory($zipfile, "$fld/steamcmd")
    Write-Host "Removing $fld/steamcmd.zip"
    Remove-Item -Path $zipfile
}

# download css dedicated server
Write-Host "Downloading CSS Dedicated Server through SteamCMD"
& "$fld/steamcmd/steamcmd.exe" +login anonymous +force_install_dir "$fld\css" +app_update 232330 +quit

# set correct path to css data in gmod
Write-Host "Configuring GMod to find CSS Dedicated Server"
$gmodpath = GetSteamAppPath 4000 GarrysMod
if ($gmodpath) {
    $mountfile = "$gmodpath\garrysmod\cfg\mount.cfg"
    if (Test-Path $mountfile) {
        (Get-Content $mountfile -Encoding UTF8) | % {
            if ($_ -match '"cstrike"') {
                "    `"cstrike`"	`"$fld\css\cstrike`""
            }
            else {
                $_
            }
        } | Set-Content $mountfile
    }
    else {
        [System.Windows.Forms.MessageBox]::Show("Soubor mount.cfg nenalezen v $mountfile, nelze nakonfigurovat propojen s CSS", "Chyba", "OK", "Error")
        Exit
    }
}
else {
    [System.Windows.Forms.MessageBox]::Show("GMod nenalezen, nelze nakonfigurovat propojen s CSS", "Chyba", "OK", "Error")
    Exit
}

[System.Windows.Forms.MessageBox]::Show("CSS Dedicated Server byl spn staen a propojen s GMod nakonfigurovno", "spch", "OK", "Info")